function [ phi ] = ao_1s( x,y,z,xi,yi,zi,Za,a0 )
%
% calculates the wavefunction of the 1s Atomic Orbital
%
% function [ phi ] = ao_1s(x,y,z,xi,yi,zi,Za,a0 )
%
% Laplacepsi       	result of the Laplace transformation
% x                 values for the x-direction
% y                 values for the y-direction
% z                 values for the z-direction
% xi                values for the second radius
% yi                values for the second radius
% zi                values for the second radius
% Za                Atomic number 
% a0                Bohr radius

%% Declear values
% r    length between the two input positions
% d    comparison value between r and delta

r = sqrt(((x-xi).^2)+((y-yi).^2)+((z-zi).^2));

%% Calculation

phi = sqrt((Za.^3)/(pi*a0.^3))*(exp(-Za*r/a0));

end


